@@ -2,7 +2,7 @@
  * UFRaw - Unidentified Flying Raw converter for digital camera images
  *
  * ufraw_icons.c - load icons for UFRaw's GUI.
- * Copyright 2004-2009 by Udi Fuchs
+ * Copyright 2004-2011 by Udi Fuchs
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -10,16 +10,12 @@
  * (at your option) any later version.
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#include <gtk/gtk.h>
 #include "ufraw.h"
 #include "icons/ufraw_icons.h"
+#include <gtk/gtk.h>
 
 static GdkPixbuf *load_icon(GtkIconFactory *factory,
-    const guint8 *icon,const char *name)
+                            const guint8 *icon, const char *name)
 {
     GdkPixbuf *pixbuf = gdk_pixbuf_new_from_inline(-1, icon, FALSE, NULL);
     GtkIconSet *iconset = gtk_icon_set_new_from_pixbuf(pixbuf);
@@ -53,6 +49,9 @@ void ufraw_icons_init()
     load_icon(factory, rotate_90_24, "object-rotate-right");
     load_icon(factory, rotate_270_24, "object-rotate-left");
     load_icon(factory, lock_24, "object-lock");
+    load_icon(factory, unlock_24, "object-unlock");
+    load_icon(factory, automatic_24, "object-automatic");
+    load_icon(factory, manual_24, "object-manual");
     load_icon(factory, exif_24, "exif");
     load_icon(factory, crop_24, "crop");
     load_icon(factory, rectify_24, "rectify");
